@@ -162,7 +162,7 @@ class CompliantSeries(
         with_replacement: bool,
         seed: int | None,
     ) -> Self: ...
-    def scatter(self, indices: int | Sequence[int], values: Any) -> Self: ...
+    def scatter(self, indices: Self, values: Self) -> Self: ...
     def shift(self, n: int) -> Self: ...
     def skew(self) -> float | None: ...
     def sort(self, *, descending: bool, nulls_last: bool) -> Self: ...
