@@ -580,7 +580,9 @@ def _get_deps_info() -> dict[str, str]:
             result[dist_name] = dist_version
         else:  # prefix match
             for target in target_names:
-                if not result[target] and dist_name.startswith(target):
+                if not result[target] and dist_name.startswith(
+                    target
+                ):  # pragma: no cover
                     result[target] = dist_version
                     break
 
@@ -1258,7 +1260,9 @@ def _expr_with_horizontal_op(name: str, *exprs: IntoExpr, **kwargs: Any) -> Expr
         msg = f"At least one expression must be passed to `{name}`"
         raise ValueError(msg)
     return Expr(
-        ExprNode(ExprKind.ELEMENTWISE, name, *exprs, **kwargs, allow_multi_output=True)
+        ExprNode(
+            ExprKind.ELEMENTWISE, name, exprs=exprs, **kwargs, allow_multi_output=True
+        )
     )
 
 
@@ -1371,8 +1375,7 @@ class When:
             ExprNode(
                 ExprKind.ELEMENTWISE,
                 "when_then",
-                self._predicate,
-                value,
+                exprs=(self._predicate, value),
                 allow_multi_output=False,
             )
         )
@@ -1381,7 +1384,9 @@ class When:
 class Then(Expr):
     def otherwise(self, value: IntoExpr | NonNestedLiteral) -> Expr:
         node = self._nodes[0]
-        return Expr(ExprNode(ExprKind.ELEMENTWISE, "when_then", *node.exprs, value))
+        return Expr(
+            ExprNode(ExprKind.ELEMENTWISE, "when_then", exprs=(*node.exprs, value))
+        )
 
 
 def when(*predicates: IntoExpr | Iterable[IntoExpr]) -> When:
@@ -1675,7 +1680,7 @@ def concat_str(
         |   full_sentence  |
         | 0   2 dogs play  |
         | 1   4 cats swim  |
-        | 2          None  |
+        | 2           NaN  |
         └──────────────────┘
     """
     flat_exprs = flatten([*flatten([exprs]), *more_exprs])
@@ -1744,7 +1749,9 @@ def coalesce(
         raise TypeError(msg)
 
     return Expr(
-        ExprNode(ExprKind.ELEMENTWISE, "coalesce", *flat_exprs, allow_multi_output=True)
+        ExprNode(
+            ExprKind.ELEMENTWISE, "coalesce", exprs=flat_exprs, allow_multi_output=True
+        )
     )
 
 
