@@ -23,7 +23,7 @@ class Selector(Expr):
             msg = "unsupported operand type(s) for op: ('Selector' + 'Selector')"
             raise TypeError(msg)
         return self._to_expr()._append_node(
-            ExprNode(ExprKind.ELEMENTWISE, "__add__", other, str_as_lit=True)
+            ExprNode(ExprKind.ELEMENTWISE, "__add__", exprs=(other,), str_as_lit=True)
         )
 
     def __or__(self, other: Any) -> Expr:  # type: ignore[override]
@@ -32,13 +32,13 @@ class Selector(Expr):
                 ExprNode(
                     ExprKind.ELEMENTWISE,
                     "__or__",
-                    other,
+                    exprs=(other,),
                     str_as_lit=True,
                     allow_multi_output=True,
                 )
             )
         return self._to_expr()._append_node(
-            ExprNode(ExprKind.ELEMENTWISE, "__or__", other, str_as_lit=True)
+            ExprNode(ExprKind.ELEMENTWISE, "__or__", exprs=(other,), str_as_lit=True)
         )
 
     def __and__(self, other: Any) -> Expr:  # type: ignore[override]
@@ -47,13 +47,13 @@ class Selector(Expr):
                 ExprNode(
                     ExprKind.ELEMENTWISE,
                     "__and__",
-                    other,
+                    exprs=(other,),
                     str_as_lit=True,
                     allow_multi_output=True,
                 )
             )
         return self._to_expr()._append_node(
-            ExprNode(ExprKind.ELEMENTWISE, "__and__", other, str_as_lit=True)
+            ExprNode(ExprKind.ELEMENTWISE, "__and__", exprs=(other,), str_as_lit=True)
         )
 
     def __rsub__(self, other: Any) -> NoReturn:
