@@ -740,7 +740,7 @@ def narwhalify(
     def decorator(func: Callable[..., Any]) -> Callable[..., Any]:
         @wraps(func)
         def wrapper(*args: Any, **kwargs: Any) -> Any:
-            args = [
+            args_nw = [
                 from_native(
                     arg,
                     pass_through=pass_through,
@@ -750,9 +750,9 @@ def narwhalify(
                     allow_series=allow_series,
                 )
                 for arg in args
-            ]  # type: ignore[assignment]
+            ]
 
-            kwargs = {
+            kwargs_nw = {
                 name: from_native(
                     value,
                     pass_through=pass_through,
@@ -766,7 +766,7 @@ def narwhalify(
 
             backends = {
                 b()
-                for v in (*args, *kwargs.values())
+                for v in (*args_nw, *kwargs_nw.values())
                 if (b := getattr(v, "__native_namespace__", None))
             }
 
@@ -774,7 +774,7 @@ def narwhalify(
                 msg = "Found multiple backends. Make sure that all dataframe/series inputs come from the same backend."
                 raise ValueError(msg)
 
-            result = func(*args, **kwargs)
+            result = func(*args_nw, **kwargs_nw)
 
             return to_native(result, pass_through=pass_through)
 
